@@ -50,6 +50,7 @@ from .._tls import (
     raise_expired_not_yet_valid,
     raise_handshake,
     raise_hostname,
+    raise_lifetime_too_long,
     raise_no_issuer,
     raise_protocol_error,
     raise_protocol_version,
@@ -103,7 +104,7 @@ def _read_callback(connection_id, data_buffer, data_length_pointer):
     Callback called by Secure Transport to actually read the socket
 
     :param connection_id:
-        An integer identifing the connection
+        An integer identifying the connection
 
     :param data_buffer:
         A char pointer FFI type to write the data to
@@ -218,7 +219,7 @@ def _write_callback(connection_id, data_buffer, data_length_pointer):
     Callback called by Secure Transport to actually write to the socket
 
     :param connection_id:
-        An integer identifing the connection
+        An integer identifying the connection
 
     :param data_buffer:
         A char pointer FFI type containing the data to write
@@ -463,7 +464,7 @@ class TLSSocket(object):
     def __init__(self, address, port, timeout=10, session=None):
         """
         :param address:
-            A unicode string of the domain name or IP address to conenct to
+            A unicode string of the domain name or IP address to connect to
 
         :param port:
             An integer of the port number to connect to
@@ -875,6 +876,7 @@ class TLSSocket(object):
                     expired = result_code == SecurityConst.CSSMERR_TP_CERT_EXPIRED
                     not_yet_valid = result_code == SecurityConst.CSSMERR_TP_CERT_NOT_VALID_YET
                     bad_hostname = result_code == SecurityConst.CSSMERR_APPLETP_HOSTNAME_MISMATCH
+                    validity_too_long = result_code == SecurityConst.CSSMERR_TP_CERT_SUSPENDED
 
                     # On macOS 10.12, some expired certificates return errSSLInternal
                     if osx_version_info >= (10, 12):
@@ -903,6 +905,9 @@ class TLSSocket(object):
                 elif self_signed:
                     raise_self_signed(cert)
 
+                elif validity_too_long:
+                    raise_lifetime_too_long(cert)
+
                 if detect_client_auth_request(self._server_hello):
                     raise_client_auth()
 
